==> cosmo_1.0.tar.gz: cosmo/src/INCLUDE/estarts.h <==
int getStarts(
	       DATASET *dataSet  /* the dataset */
	       );


int initSvSpace(
		 DATASET *dataSet
		 );


int getMaxNnSites(
		   DATASET *dataSet   /* the dataset */
		   );

BOOLEAN satisfiesConstraints(
			     double *pwm,   /* the PWM of the candidate starting value */
			     int width,     /* the width of this PWM */
			     MODEL *mod     /* the interpreted constraint set to check against */
			     );

BOOLEAN checkPWMBounds(
		       double *pwm,   /* PWM of candidate starting value */
		       int width,     /* width of this PWM */
		       MODEL *mod     /* interpreted constraint set */
		       );

BOOLEAN checkLinFreqCons(
			 double *pwm,   /* PWM of candidate starting value */
			 int width,     /* width of this PWM */
			 MODEL *mod     /* interpreted constraint set */
			 );


int seq2logPwm(
		int *lpwm,          /* on exit: the log-transformed PWM */
		int *seq,           /* the sequence from which to construct the PWM */
		int width,          /* the width of the motif */
		double hiProb       /* the probability to assign to observed nucleotides */
		);


int addCol2lPwm(
		 int *lPwm,     /* the PWM to which we are adding a column */
		 int *seq,      /* the sequence from which the PWM was constructed */
		 int start,     /* the starting position of the corresponding oligo */
		 int newWidth,  /* the new width of the PWM */
		 double hiProb  /* the probability to assign to observed nucleotides */
		 );


int getEvalStarts(
		   DATASET *dataSet  /* the dataset */
		   );

int eGetNewMProbs(
		   DATASET *dataSet,    /* the dataset */
		   int *lPwm,           /* PWM for which to calculate motif probabilities */ 
		   int width,           /* width of this PWM */
		   int spaceNum,        /* store mProbs in mProbs1 or mProbs2 ? */
		   BOOLEAN excludeAny,  /* are any sequences to be excluded for CV purposes? */
		   int *excludeCv       /* array indicating which sequences are to be exclude, NULL if none are to be excluded */
		   );

int eGetHigherMProbs(
		      DATASET *dataSet,    /* the dataset */
		      int *lPwm,           /* log-transformed PWM for which motif probabilities are desired */
		      int width,           /* widht of this PWM */
		      int spaceNum         /* are motif probs for width-1 stored in mProbs1 or mProbs2 ? */
		      );

int eGetOverMProbs(
		    DATASET *dataSet,  /* the dataset */
		    int *lPwm,         /* the log-transformed PWM for which to find the motif probabilities */
		    int *prevLPwm,     /* the log-transformed PWM for width+1 starting in the previous position */
		    int width,         /* the width of the current PWM */
		    int spaceNum,      /* are old motif probs stored in mProbs1 or mProbs2 ? */
		    BOOLEAN oneWidth   /* is there only one candidate width? */
		    );

int copyIntMotProbs(
		     INTMOTPROB *from,   /* copy these motif probabilities */
		     INTMOTPROB *to,     /* into this array */
		     DATASET *dataSet    /* the data set */
		     );


int compIntMotProbs(
		    const void *x,   /* pointer to first motif probability */
		    const void *y    /* pointer to second motif probability */
		    );

int sortIntMotProbs(
		    DATASET *dataSet,   /* the dataset */
		    int spaceNum,       /* are motif probs stored in intMotProbs1 or intMotProbs2? */
		    BOOLEAN global,     /* global sort or within sequences? */
		    int width           /* width of motif */
		    );

int insertSv(
	      THETA *svTheta,    /* array of starting values */
	      int where,         /* where in this array are we inserting a starting value? */
	      double *pwm,       /* position weight matrix of starting value to be inserted */
	      double score,      /* score of this starting value */
	      int width          /* width of the position weight matrix */
	      );

int compTheta(
	      const void *x,   /* first starting value */ 
	      const void *y    /* second starting value */
	      );


int checkStart(
		DATASET *dataSet,   /* the dataset */
		int spaceNum,       /* are motif probs stored in intMotProb1 or intMotProb2? */
		int width           /* width of motif */
		);

int isDup(
	  double *pwm,        /* candidate PWM */
	  int width,          /* its width */
	  THETA *svTheta,     /* array of recorded starting values */
	  int numSv           /* number of recorded starting values */
	  );


int getBestNSites(
		   THETA *theta,         /* parameter estimates */
		   DATASET *dataSet      /* the dataset */
		   );


double getIntensity(
		    MTYPE mType,          /* model type */
 		    int width,            /* width of motif */
		    int numSites,         /* expected number of motif occurrences */
		    DATASET *dataSet      /* the dataset */
		    );
int completeSv(
		DATASET *dataSet   /* the dataset */
		);

int switchMod(
	       THETA *theta,           /* parameter estimates */
	       MTYPE mType,            /* model type to switch to */ 
	       DATASET *dataSet        /* the dataset */
	       );

==> cosmo_1.6.0.tar.gz: cosmo/src/INCLUDE/estarts.h <==
int getStarts(
	       DATASET *dataSet  /* the dataset */
	       );


int initSvSpace(
		DATASET *dataSet,
		SVSPACE *baseSvSpace
		);



BOOLEAN satisfiesConstraints(
			     double *pwm,   /* the PWM of the candidate starting value */
			     int width,     /* the width of this PWM */
			     MODEL *mod     /* the interpreted constraint set to check against */
			     );

BOOLEAN checkPWMBounds(
		       double *pwm,   /* PWM of candidate starting value */
		       int width,     /* width of this PWM */
		       MODEL *mod     /* interpreted constraint set */
		       );

BOOLEAN checkLinFreqCons(
			 double *pwm,   /* PWM of candidate starting value */
			 int width,     /* width of this PWM */
			 MODEL *mod     /* interpreted constraint set */
			 );


int seq2logPwm(
		int *lpwm,          /* on exit: the log-transformed PWM */
		int *seq,           /* the sequence from which to construct the PWM */
		int width,          /* the width of the motif */
		double hiProb       /* the probability to assign to observed nucleotides */
		);


int addCol2lPwm(
		 int *lPwm,     /* the PWM to which we are adding a column */
		 int *seq,      /* the sequence from which the PWM was constructed */
		 int start,     /* the starting position of the corresponding oligo */
		 int newWidth,  /* the new width of the PWM */
		 double hiProb  /* the probability to assign to observed nucleotides */
		 );


int getEvalStarts(
		   DATASET *dataSet  /* the dataset */
		   );

int eGetNewMProbs(
		   DATASET *dataSet,    /* the dataset */
		   int *lPwm,           /* PWM for which to calculate motif probabilities */ 
		   int width,           /* width of this PWM */
		   int spaceNum         /* store mProbs in mProbs1 or mProbs2 ? */
		   );

int eGetHigherMProbs(
		      DATASET *dataSet,    /* the dataset */
		      int *lPwm,           /* log-transformed PWM for which motif probabilities are desired */
		      int width,           /* widht of this PWM */
		      int spaceNum         /* are motif probs for width-1 stored in mProbs1 or mProbs2 ? */
		      );

int eGetOverMProbs(
		    DATASET *dataSet,  /* the dataset */
		    int *lPwm,         /* the log-transformed PWM for which to find the motif probabilities */
		    int *prevLPwm,     /* the log-transformed PWM for width+1 starting in the previous position */
		    int width,         /* the width of the current PWM */
		    int spaceNum,      /* are old motif probs stored in mProbs1 or mProbs2 ? */
		    BOOLEAN oneWidth   /* is there only one candidate width? */
		    );

int copyIntMotProbs(
		     INTMOTPROB *from,   /* copy these motif probabilities */
		     INTMOTPROB *to,     /* into this array */
		     DATASET *dataSet    /* the data set */
		     );


int compIntMotProbs(
		    const void *x,   /* pointer to first motif probability */
		    const void *y    /* pointer to second motif probability */
		    );

int sortIntMotProbs(
		    DATASET *dataSet,   /* the dataset */
		    int spaceNum,       /* are motif probs stored in intMotProbs1 or intMotProbs2? */
		    BOOLEAN global,     /* global sort or within sequences? */
		    int width           /* width of motif */
		    );

int insertSv(
	      THETA *svTheta,    /* array of starting values */
	      int where,         /* where in this array are we inserting a starting value? */
	      double *pwm,       /* position weight matrix of starting value to be inserted */
	      double score,      /* score of this starting value */
	      int width,         /* width of the position weight matrix */
	      int numSites       /* number of sites */
	      );

int compTheta(
	      const void *x,   /* first starting value */ 
	      const void *y    /* second starting value */
	      );


int checkStart(
		DATASET *dataSet,    /* the dataset */
		int spaceNum,        /* are motif probs stored in intMotProb1 or intMotProb2? */
		int width,           /* width of motif */
		SVSPACE *baseSvSpace /* starting value space to use */
		);

int isDup(
	  double *pwm,        /* candidate PWM */
	  int width,          /* its width */
	  THETA *svTheta,     /* array of recorded starting values */
	  int numSv           /* number of recorded starting values */
	  );


int getBestNSites(
		   THETA *theta,         /* parameter estimates */
		   DATASET *dataSet      /* the dataset */
		   );


int completeSv(
	       DATASET *dataSet,    /* the dataset */
	       SVSPACE *baseSvSpace /* starting value space to use */
	       );

int switchMod(
	       THETA *theta,           /* parameter estimates */
	       MTYPE mType,            /* model type to switch to */ 
	       DATASET *dataSet        /* the dataset */
	       );
